/*
	Convert Unix Time - Date and Time Converter
	Copyright © 2004-2015 Harry Whitfield

	This program is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by the
	Free Software Foundation; either version 2 of the License, or (at your
	option) any later version.

	This program is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.

	You should have received a copy of the GNU General Public License along
	with this program; if not, write to the Free Software Foundation, Inc.,
	51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
	
	Convert Unix Time - browser version 1.0
	6 May, 2015
	Copyright © 2004-2015 Harry Whitfield
	mailto:g6auc@arrl.net
*/

/*global paramOne, paramTwo, paramThree, paramFour, headingFour, Menu, convertTime,
	convertToLocale, convertToUTC, theUnixTime
*/

/*properties
    floor, getMilliseconds, getSeconds, getTime, keyCode, onchange, onkeypress,
    toUTCString, value, which
*/

// map custom names onto model names
var inputtime     = paramOne;
var localtime     = paramTwo;
var universaltime = paramThree;
var outputtime    = paramFour;
/*
var localdateHeading     = headingOne;
var localtimeHeading     = headingTwo;
var universaltimeHeading = headingThree;
*/
var outputtimeHeading    = headingFour;

var convModeMenu = Menu[0];
var updateMenu   = Menu[1];

var typePref = 'GPS Week';
var tickPref = 'Never';

var gDate;
var clockOn  = false;
var fastTick = false;
var intervalID = null;

/*
	['GPS Week', 'Internet Time', 'Julian Date', 'Macintosh Time', 'Modified Julian Date', 'NTP Time'],
	['Once a Second', 'Once a Minute', 'Never']
*/

function displayTime() {	// clock mode
	var secs = 0,
		timerInterval, 
		d = new Date(),
		ts = Math.floor(d.getTime() / 1000),
		ms;
		
	if (!fastTick) {
		if (intervalID !== null) { clearInterval(intervalID); intervalID = null; }
		secs = d.getSeconds();
		ms = d.getMilliseconds();
		timerInterval = 60 - secs;
		if (timerInterval > 10) { timerInterval -= 5; }
		timerInterval = 1000 * timerInterval - ms;
		intervalID = setInterval(displayTime, timerInterval);
	}

	if (fastTick || (secs <= 1) || (secs > 58)) {
		inputtime.value     = ts;
		localtime.value     = convertToLocale(ts);
   		universaltime.value = d.toUTCString();
		outputtime.value    = convertTime(ts, typePref);
	}
}

function displayData(ts) {
	localtime.value     = convertToLocale(ts);
	universaltime.value = convertToUTC(ts);
	outputtime.value    = convertTime(ts, typePref);
}

function setNow() {
	inputtime.value = theUnixTime();
	displayData(inputtime.value);
}

function updatePrefs() {
	outputtimeHeading.value = typePref;
	clockOn  = (tickPref !== 'Never');
	fastTick = (tickPref === "Once a Second");
	setNow();
	
	if (intervalID !== null) { clearInterval(intervalID); intervalID = null; }

	if (clockOn) {	
		intervalID = setInterval(displayTime, 1000);
	}
}

convModeMenu.onchange  = function () {
	typePref = this.value;
	updatePrefs();
};

updateMenu.onchange  = function () {
	tickPref = this.value;
	updatePrefs();
};

inputtime.onkeypress = function (event) {
	var x = event.which || event.keyCode,
		ts;
	
	if (x === 13) { 
		ts = parseInt(inputtime.value, 10);
		if (!isNaN(ts)) {
			displayData(ts);
		} else {
			outputtime.value = "Illegal Timestamp";
		}
	} else {
		localtime.value = "";
		universaltime.value = "";
		outputtime.value = "";
	}
};

updatePrefs();
